Documentation
¶
Overview ¶
Code generated from Pkl module `collections`. DO NOT EDIT.
Code generated from Pkl module `collections`. DO NOT EDIT.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Collections ¶
type Collections struct {
Res1 []int `pkl:"res1"`
Res2 []int `pkl:"res2"`
Res3 [][]int `pkl:"res3"`
Res4 [][]int `pkl:"res4"`
Res5 map[int]bool `pkl:"res5"`
Res6 map[int]map[int]bool `pkl:"res6"`
Res7 map[int]bool `pkl:"res7"`
Res8 map[int]map[int]bool `pkl:"res8"`
Res9 map[string]struct{} `pkl:"res9"`
Res10 map[int8]struct{} `pkl:"res10"`
Res11 *pkl.Pair[int, float64] `pkl:"res11"`
Res12 *pkl.Pair[any, any] `pkl:"res12"`
Res13 *pkl.Pair[int, *int] `pkl:"res13"`
}
func Load ¶
func Load(ctx context.Context, evaluator pkl.Evaluator, source *pkl.ModuleSource) (*Collections, error)
Load loads the pkl module at the given source and evaluates it with the given evaluator into a Collections
func LoadFromPath ¶
func LoadFromPath(ctx context.Context, path string) (ret *Collections, err error)
LoadFromPath loads the pkl module at the given path and evaluates it into a Collections
Click to show internal directories.
Click to hide internal directories.