Documentation
¶
Overview ¶
Code generated from Pkl module `primitives`. DO NOT EDIT.
Code generated from Pkl module `primitives`. DO NOT EDIT.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Primitives ¶
type Primitives struct {
Res0 string `pkl:"res0"`
Res1 int `pkl:"res1"`
Res2 int8 `pkl:"res2"`
Res3 int16 `pkl:"res3"`
Res4 int32 `pkl:"res4"`
Res5 uint `pkl:"res5"`
Res6 uint8 `pkl:"res6"`
Res7 uint16 `pkl:"res7"`
Res8 uint32 `pkl:"res8"`
Res9 float64 `pkl:"res9"`
Res10 bool `pkl:"res10"`
Res11 any `pkl:"res11"`
Res12 float64 `pkl:"res12"`
Res13 float64 `pkl:"res13"`
}
func Load ¶
func Load(ctx context.Context, evaluator pkl.Evaluator, source *pkl.ModuleSource) (*Primitives, error)
Load loads the pkl module at the given source and evaluates it with the given evaluator into a Primitives
func LoadFromPath ¶
func LoadFromPath(ctx context.Context, path string) (ret *Primitives, err error)
LoadFromPath loads the pkl module at the given path and evaluates it into a Primitives
Click to show internal directories.
Click to hide internal directories.